# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.webhooks_api import WebhooksApi  # noqa: E501
from wire4_client.rest import ApiException


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self):
        self.api = api.webhooks_api.WebhooksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_webhook(self):
        """Test case for get_webhook

        Consulta de Webhook  # noqa: E501
        """
        pass

    def test_get_webhooks(self):
        """Test case for get_webhooks

        Consulta la lista de Webhooks  # noqa: E501
        """
        pass

    def test_register_webhook(self):
        """Test case for register_webhook

        Alta de Webhook  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wire4_client.api_client import ApiClient


class PuntosDeVentaCoDiApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_sales_point(self, body, authorization, company_id, **kwargs):  # noqa: E501
        """Registro de punto de venta.  # noqa: E501

        Se registra un punto de venta (TPV) desde donde se emitarán los cobros CODI®. El punto de venta se debe asociar a un cuenta CLABE registrada previamente ante Banxico para realizar cobros con CODI®.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_sales_point(body, authorization, company_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SalesPointRequest body: Es el objeto que contiene información del punto de venta CODI®. (required)
        :param str authorization: Header para token (required)
        :param str company_id: Es el identificador de la empresa. (required)
        :return: SalesPointRespose
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_sales_point_with_http_info(body, authorization, company_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_sales_point_with_http_info(body, authorization, company_id, **kwargs)  # noqa: E501
            return data

    def create_sales_point_with_http_info(self, body, authorization, company_id, **kwargs):  # noqa: E501
        """Registro de punto de venta.  # noqa: E501

        Se registra un punto de venta (TPV) desde donde se emitarán los cobros CODI®. El punto de venta se debe asociar a un cuenta CLABE registrada previamente ante Banxico para realizar cobros con CODI®.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_sales_point_with_http_info(body, authorization, company_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SalesPointRequest body: Es el objeto que contiene información del punto de venta CODI®. (required)
        :param str authorization: Header para token (required)
        :param str company_id: Es el identificador de la empresa. (required)
        :return: SalesPointRespose
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'company_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_sales_point" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_sales_point`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `create_sales_point`")  # noqa: E501
        # verify the required parameter 'company_id' is set
        if ('company_id' not in params or
                params['company_id'] is None):
            raise ValueError("Missing the required parameter `company_id` when calling `create_sales_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'company_id' in params:
            query_params.append(('companyId', params['company_id']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/codi/companies/salespoint', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SalesPointRespose',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def obtain_sale_points(self, authorization, company_id, **kwargs):  # noqa: E501
        """Consulta de puntos de venta  # noqa: E501

        Obtiene los puntos de venta asociados a una empresa en las cuales se hacen operaciones CODI®.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.obtain_sale_points(authorization, company_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str company_id: Es el identificador de la empresa. Ejemplo: 8838d513-5916-4662-bb30-2448f0f543ed (required)
        :return: list[SalesPointFound]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.obtain_sale_points_with_http_info(authorization, company_id, **kwargs)  # noqa: E501
        else:
            (data) = self.obtain_sale_points_with_http_info(authorization, company_id, **kwargs)  # noqa: E501
            return data

    def obtain_sale_points_with_http_info(self, authorization, company_id, **kwargs):  # noqa: E501
        """Consulta de puntos de venta  # noqa: E501

        Obtiene los puntos de venta asociados a una empresa en las cuales se hacen operaciones CODI®.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.obtain_sale_points_with_http_info(authorization, company_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str company_id: Es el identificador de la empresa. Ejemplo: 8838d513-5916-4662-bb30-2448f0f543ed (required)
        :return: list[SalesPointFound]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'company_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method obtain_sale_points" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `obtain_sale_points`")  # noqa: E501
        # verify the required parameter 'company_id' is set
        if ('company_id' not in params or
                params['company_id'] is None):
            raise ValueError("Missing the required parameter `company_id` when calling `obtain_sale_points`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'company_id' in params:
            query_params.append(('companyId', params['company_id']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/codi/companies/salespoint', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SalesPointFound]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MessageCodiAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'concept': 'str',
        'due_date': 'datetime',
        'id': 'str',
        'metadata': 'str',
        'operation_date': 'datetime',
        'order_id': 'str',
        'payment_type': 'str',
        'reference': 'str',
        'sales_point_id': 'str',
        'status': 'str',
        'transaction_id': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'concept': 'concept',
        'due_date': 'due_date',
        'id': 'id',
        'metadata': 'metadata',
        'operation_date': 'operation_date',
        'order_id': 'order_id',
        'payment_type': 'payment_type',
        'reference': 'reference',
        'sales_point_id': 'sales_point_id',
        'status': 'status',
        'transaction_id': 'transaction_id'
    }

    def __init__(self, amount=None, concept=None, due_date=None, id=None, metadata=None, operation_date=None, order_id=None, payment_type=None, reference=None, sales_point_id=None, status=None, transaction_id=None):  # noqa: E501
        """MessageCodiAction - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._concept = None
        self._due_date = None
        self._id = None
        self._metadata = None
        self._operation_date = None
        self._order_id = None
        self._payment_type = None
        self._reference = None
        self._sales_point_id = None
        self._status = None
        self._transaction_id = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if concept is not None:
            self.concept = concept
        if due_date is not None:
            self.due_date = due_date
        if id is not None:
            self.id = id
        if metadata is not None:
            self.metadata = metadata
        if operation_date is not None:
            self.operation_date = operation_date
        if order_id is not None:
            self.order_id = order_id
        if payment_type is not None:
            self.payment_type = payment_type
        if reference is not None:
            self.reference = reference
        if sales_point_id is not None:
            self.sales_point_id = sales_point_id
        if status is not None:
            self.status = status
        if transaction_id is not None:
            self.transaction_id = transaction_id

    @property
    def amount(self):
        """Gets the amount of this MessageCodiAction.  # noqa: E501

        Es el monto de la operación de pago.  # noqa: E501

        :return: The amount of this MessageCodiAction.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this MessageCodiAction.

        Es el monto de la operación de pago.  # noqa: E501

        :param amount: The amount of this MessageCodiAction.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def concept(self):
        """Gets the concept of this MessageCodiAction.  # noqa: E501

        Es el concepto de la transacción.  # noqa: E501

        :return: The concept of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._concept

    @concept.setter
    def concept(self, concept):
        """Sets the concept of this MessageCodiAction.

        Es el concepto de la transacción.  # noqa: E501

        :param concept: The concept of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._concept = concept

    @property
    def due_date(self):
        """Gets the due_date of this MessageCodiAction.  # noqa: E501

        Es la fecha de expiración de la operación.  # noqa: E501

        :return: The due_date of this MessageCodiAction.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this MessageCodiAction.

        Es la fecha de expiración de la operación.  # noqa: E501

        :param due_date: The due_date of this MessageCodiAction.  # noqa: E501
        :type: datetime
        """

        self._due_date = due_date

    @property
    def id(self):
        """Gets the id of this MessageCodiAction.  # noqa: E501

        Es el UUID de la operación.  # noqa: E501

        :return: The id of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MessageCodiAction.

        Es el UUID de la operación.  # noqa: E501

        :param id: The id of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def metadata(self):
        """Gets the metadata of this MessageCodiAction.  # noqa: E501

        Es el campo Metadata asociado a la petición de pago. Es información que indica guardar la petición.  # noqa: E501

        :return: The metadata of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this MessageCodiAction.

        Es el campo Metadata asociado a la petición de pago. Es información que indica guardar la petición.  # noqa: E501

        :param metadata: The metadata of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._metadata = metadata

    @property
    def operation_date(self):
        """Gets the operation_date of this MessageCodiAction.  # noqa: E501

        Es la fecha de la operación.  # noqa: E501

        :return: The operation_date of this MessageCodiAction.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date

    @operation_date.setter
    def operation_date(self, operation_date):
        """Sets the operation_date of this MessageCodiAction.

        Es la fecha de la operación.  # noqa: E501

        :param operation_date: The operation_date of this MessageCodiAction.  # noqa: E501
        :type: datetime
        """

        self._operation_date = operation_date

    @property
    def order_id(self):
        """Gets the order_id of this MessageCodiAction.  # noqa: E501

        Es el identificador de la petición.  # noqa: E501

        :return: The order_id of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this MessageCodiAction.

        Es el identificador de la petición.  # noqa: E501

        :param order_id: The order_id of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def payment_type(self):
        """Gets the payment_type of this MessageCodiAction.  # noqa: E501

        Es el tipo de pago.  # noqa: E501

        :return: The payment_type of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """Sets the payment_type of this MessageCodiAction.

        Es el tipo de pago.  # noqa: E501

        :param payment_type: The payment_type of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._payment_type = payment_type

    @property
    def reference(self):
        """Gets the reference of this MessageCodiAction.  # noqa: E501

        Es el número de referencia.  # noqa: E501

        :return: The reference of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this MessageCodiAction.

        Es el número de referencia.  # noqa: E501

        :param reference: The reference of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def sales_point_id(self):
        """Gets the sales_point_id of this MessageCodiAction.  # noqa: E501

        Identidicador del punto de venta a la que pertenece la petición de pago.  # noqa: E501

        :return: The sales_point_id of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._sales_point_id

    @sales_point_id.setter
    def sales_point_id(self, sales_point_id):
        """Sets the sales_point_id of this MessageCodiAction.

        Identidicador del punto de venta a la que pertenece la petición de pago.  # noqa: E501

        :param sales_point_id: The sales_point_id of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._sales_point_id = sales_point_id

    @property
    def status(self):
        """Gets the status of this MessageCodiAction.  # noqa: E501

        Es el estado (estatus) de la operación de pago.  # noqa: E501

        :return: The status of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this MessageCodiAction.

        Es el estado (estatus) de la operación de pago.  # noqa: E501

        :param status: The status of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def transaction_id(self):
        """Gets the transaction_id of this MessageCodiAction.  # noqa: E501

        Es el identificador de la transacción.  # noqa: E501

        :return: The transaction_id of this MessageCodiAction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this MessageCodiAction.

        Es el identificador de la transacción.  # noqa: E501

        :param transaction_id: The transaction_id of this MessageCodiAction.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageCodiAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageCodiAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wire4_client.api_client import ApiClient


class ContractsDetailsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_authorization(self, body, authorization, **kwargs):  # noqa: E501
        """Devuelve la URL para autorización del usuario Monex  # noqa: E501

        Se obtiene la URL para la autorización del usuario Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_authorization(body, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PreMonexAuthorization body: Información para la autorización (required)
        :param str authorization: Header para token (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_authorization_with_http_info(body, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.create_authorization_with_http_info(body, authorization, **kwargs)  # noqa: E501
            return data

    def create_authorization_with_http_info(self, body, authorization, **kwargs):  # noqa: E501
        """Devuelve la URL para autorización del usuario Monex  # noqa: E501

        Se obtiene la URL para la autorización del usuario Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_authorization_with_http_info(body, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PreMonexAuthorization body: Información para la autorización (required)
        :param str authorization: Header para token (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_authorization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_authorization`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `create_authorization`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/onboarding/accounts/authorize', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenRequiredResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def obtain_authorized_users(self, authorization, x_access_key, request_id, **kwargs):  # noqa: E501
        """Obtiene los usuarios autorizados  # noqa: E501

        Obtienen los detalles de los usuarios autorizados de Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.obtain_authorized_users(authorization, x_access_key, request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str x_access_key: La llave de acceso de la aplicación (required)
        :param str request_id: El identificador de la petición a esta API (required)
        :return: list[AuthorizedUsers]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.obtain_authorized_users_with_http_info(authorization, x_access_key, request_id, **kwargs)  # noqa: E501
        else:
            (data) = self.obtain_authorized_users_with_http_info(authorization, x_access_key, request_id, **kwargs)  # noqa: E501
            return data

    def obtain_authorized_users_with_http_info(self, authorization, x_access_key, request_id, **kwargs):  # noqa: E501
        """Obtiene los usuarios autorizados  # noqa: E501

        Obtienen los detalles de los usuarios autorizados de Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.obtain_authorized_users_with_http_info(authorization, x_access_key, request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str x_access_key: La llave de acceso de la aplicación (required)
        :param str request_id: El identificador de la petición a esta API (required)
        :return: list[AuthorizedUsers]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'x_access_key', 'request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method obtain_authorized_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `obtain_authorized_users`")  # noqa: E501
        # verify the required parameter 'x_access_key' is set
        if ('x_access_key' not in params or
                params['x_access_key'] is None):
            raise ValueError("Missing the required parameter `x_access_key` when calling `obtain_authorized_users`")  # noqa: E501
        # verify the required parameter 'request_id' is set
        if ('request_id' not in params or
                params['request_id'] is None):
            raise ValueError("Missing the required parameter `request_id` when calling `obtain_authorized_users`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'request_id' in params:
            path_params['requestId'] = params['request_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501
        if 'x_access_key' in params:
            header_params['X-ACCESS-KEY'] = params['x_access_key']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/onboarding/accounts/{requestId}/authorized-users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AuthorizedUsers]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def obtain_authorized_users_by_contract(self, authorization, x_access_key, **kwargs):  # noqa: E501
        """Obtiene los usuarios autorizados por contrato  # noqa: E501

        Obtienen los detalles de los usuarios autorizados por contrato Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.obtain_authorized_users_by_contract(authorization, x_access_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str x_access_key: La llave de acceso de la aplicación (required)
        :param str contract: El contrato Monex
        :return: list[AuthorizedUsers]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.obtain_authorized_users_by_contract_with_http_info(authorization, x_access_key, **kwargs)  # noqa: E501
        else:
            (data) = self.obtain_authorized_users_by_contract_with_http_info(authorization, x_access_key, **kwargs)  # noqa: E501
            return data

    def obtain_authorized_users_by_contract_with_http_info(self, authorization, x_access_key, **kwargs):  # noqa: E501
        """Obtiene los usuarios autorizados por contrato  # noqa: E501

        Obtienen los detalles de los usuarios autorizados por contrato Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.obtain_authorized_users_by_contract_with_http_info(authorization, x_access_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str x_access_key: La llave de acceso de la aplicación (required)
        :param str contract: El contrato Monex
        :return: list[AuthorizedUsers]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'x_access_key', 'contract']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method obtain_authorized_users_by_contract" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `obtain_authorized_users_by_contract`")  # noqa: E501
        # verify the required parameter 'x_access_key' is set
        if ('x_access_key' not in params or
                params['x_access_key'] is None):
            raise ValueError("Missing the required parameter `x_access_key` when calling `obtain_authorized_users_by_contract`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'contract' in params:
            query_params.append(('contract', params['contract']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501
        if 'x_access_key' in params:
            header_params['X-ACCESS-KEY'] = params['x_access_key']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/onboarding/accounts/authorized-users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AuthorizedUsers]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def obtain_contract_details(self, body, authorization, x_access_key, **kwargs):  # noqa: E501
        """Obtiene los detalles de la empresa del contrato  # noqa: E501

        Detalles de la compañía relacionada con el contrato de Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.obtain_contract_details(body, authorization, x_access_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ContractDetailRequest body: Información para obtener los detalles de la companía (required)
        :param str authorization: Header para token (required)
        :param str x_access_key: La llave de acceso de la aplicación (required)
        :return: ContractDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.obtain_contract_details_with_http_info(body, authorization, x_access_key, **kwargs)  # noqa: E501
        else:
            (data) = self.obtain_contract_details_with_http_info(body, authorization, x_access_key, **kwargs)  # noqa: E501
            return data

    def obtain_contract_details_with_http_info(self, body, authorization, x_access_key, **kwargs):  # noqa: E501
        """Obtiene los detalles de la empresa del contrato  # noqa: E501

        Detalles de la compañía relacionada con el contrato de Monex.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.obtain_contract_details_with_http_info(body, authorization, x_access_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ContractDetailRequest body: Información para obtener los detalles de la companía (required)
        :param str authorization: Header para token (required)
        :param str x_access_key: La llave de acceso de la aplicación (required)
        :return: ContractDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'x_access_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method obtain_contract_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `obtain_contract_details`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `obtain_contract_details`")  # noqa: E501
        # verify the required parameter 'x_access_key' is set
        if ('x_access_key' not in params or
                params['x_access_key'] is None):
            raise ValueError("Missing the required parameter `x_access_key` when calling `obtain_contract_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501
        if 'x_access_key' in params:
            header_params['X-ACCESS-KEY'] = params['x_access_key']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/onboarding/accounts/details', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContractDetailResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.beneficiary_institution import BeneficiaryInstitution  # noqa: F401,E501
from wire4_client.models.person import Person  # noqa: F401,E501


class Account(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_limit': 'float',
        'bank_key': 'str',
        'beneficiary_account': 'str',
        'email': 'list[str]',
        'institution': 'BeneficiaryInstitution',
        'kind_of_relationship': 'str',
        'numeric_reference_spei': 'str',
        'payment_concept_spei': 'str',
        'person': 'Person',
        'relationship': 'str',
        'rfc': 'str'
    }

    attribute_map = {
        'amount_limit': 'amount_limit',
        'bank_key': 'bank_key',
        'beneficiary_account': 'beneficiary_account',
        'email': 'email',
        'institution': 'institution',
        'kind_of_relationship': 'kind_of_relationship',
        'numeric_reference_spei': 'numeric_reference_spei',
        'payment_concept_spei': 'payment_concept_spei',
        'person': 'person',
        'relationship': 'relationship',
        'rfc': 'rfc'
    }

    def __init__(self, amount_limit=None, bank_key=None, beneficiary_account=None, email=None, institution=None, kind_of_relationship=None, numeric_reference_spei=None, payment_concept_spei=None, person=None, relationship=None, rfc=None):  # noqa: E501
        """Account - a model defined in Swagger"""  # noqa: E501
        self._amount_limit = None
        self._bank_key = None
        self._beneficiary_account = None
        self._email = None
        self._institution = None
        self._kind_of_relationship = None
        self._numeric_reference_spei = None
        self._payment_concept_spei = None
        self._person = None
        self._relationship = None
        self._rfc = None
        self.discriminator = None
        self.amount_limit = amount_limit
        if bank_key is not None:
            self.bank_key = bank_key
        self.beneficiary_account = beneficiary_account
        if email is not None:
            self.email = email
        if institution is not None:
            self.institution = institution
        self.kind_of_relationship = kind_of_relationship
        if numeric_reference_spei is not None:
            self.numeric_reference_spei = numeric_reference_spei
        if payment_concept_spei is not None:
            self.payment_concept_spei = payment_concept_spei
        if person is not None:
            self.person = person
        self.relationship = relationship
        self.rfc = rfc

    @property
    def amount_limit(self):
        """Gets the amount_limit of this Account.  # noqa: E501

        Es el monto límite permitido que se registra para la cuenta. Por ejemplo 1000.00.  # noqa: E501

        :return: The amount_limit of this Account.  # noqa: E501
        :rtype: float
        """
        return self._amount_limit

    @amount_limit.setter
    def amount_limit(self, amount_limit):
        """Sets the amount_limit of this Account.

        Es el monto límite permitido que se registra para la cuenta. Por ejemplo 1000.00.  # noqa: E501

        :param amount_limit: The amount_limit of this Account.  # noqa: E501
        :type: float
        """
        if amount_limit is None:
            raise ValueError("Invalid value for `amount_limit`, must not be `None`")  # noqa: E501

        self._amount_limit = amount_limit

    @property
    def bank_key(self):
        """Gets the bank_key of this Account.  # noqa: E501

        Es la clave del banco, es requerido en caso de que la cuenta del beneficiario sea un número de celular.  # noqa: E501

        :return: The bank_key of this Account.  # noqa: E501
        :rtype: str
        """
        return self._bank_key

    @bank_key.setter
    def bank_key(self, bank_key):
        """Sets the bank_key of this Account.

        Es la clave del banco, es requerido en caso de que la cuenta del beneficiario sea un número de celular.  # noqa: E501

        :param bank_key: The bank_key of this Account.  # noqa: E501
        :type: str
        """

        self._bank_key = bank_key

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this Account.  # noqa: E501

        Es la cuenta del beneficiario, podría ser teléfono celular (se valida que sea de 10 dígitos), Tarjeta de débito (TDD, se valida que sea de 16 dígitos) o cuenta CLABE (se valida que sea de 18 dígitos). <br/><br/>Por ejemplo Teléfono celular: 5525072600, TDD: 4323 1234 5678 9123, CLABE: 032180000118359719.  # noqa: E501

        :return: The beneficiary_account of this Account.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this Account.

        Es la cuenta del beneficiario, podría ser teléfono celular (se valida que sea de 10 dígitos), Tarjeta de débito (TDD, se valida que sea de 16 dígitos) o cuenta CLABE (se valida que sea de 18 dígitos). <br/><br/>Por ejemplo Teléfono celular: 5525072600, TDD: 4323 1234 5678 9123, CLABE: 032180000118359719.  # noqa: E501

        :param beneficiary_account: The beneficiary_account of this Account.  # noqa: E501
        :type: str
        """
        if beneficiary_account is None:
            raise ValueError("Invalid value for `beneficiary_account`, must not be `None`")  # noqa: E501

        self._beneficiary_account = beneficiary_account

    @property
    def email(self):
        """Gets the email of this Account.  # noqa: E501

        Es una lista de correos electrónicos (emails). Se valida el formato de email. Este campo es opcional.  # noqa: E501

        :return: The email of this Account.  # noqa: E501
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Account.

        Es una lista de correos electrónicos (emails). Se valida el formato de email. Este campo es opcional.  # noqa: E501

        :param email: The email of this Account.  # noqa: E501
        :type: list[str]
        """

        self._email = email

    @property
    def institution(self):
        """Gets the institution of this Account.  # noqa: E501


        :return: The institution of this Account.  # noqa: E501
        :rtype: BeneficiaryInstitution
        """
        return self._institution

    @institution.setter
    def institution(self, institution):
        """Sets the institution of this Account.


        :param institution: The institution of this Account.  # noqa: E501
        :type: BeneficiaryInstitution
        """

        self._institution = institution

    @property
    def kind_of_relationship(self):
        """Gets the kind_of_relationship of this Account.  # noqa: E501

        Es el tipo de relación que se tiene con el propietario de la cuenta. Para registrar una cuenta, este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br /><br /><b>Nota:</b> <em>Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.</em>  # noqa: E501

        :return: The kind_of_relationship of this Account.  # noqa: E501
        :rtype: str
        """
        return self._kind_of_relationship

    @kind_of_relationship.setter
    def kind_of_relationship(self, kind_of_relationship):
        """Sets the kind_of_relationship of this Account.

        Es el tipo de relación que se tiene con el propietario de la cuenta. Para registrar una cuenta, este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br /><br /><b>Nota:</b> <em>Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.</em>  # noqa: E501

        :param kind_of_relationship: The kind_of_relationship of this Account.  # noqa: E501
        :type: str
        """
        if kind_of_relationship is None:
            raise ValueError("Invalid value for `kind_of_relationship`, must not be `None`")  # noqa: E501

        self._kind_of_relationship = kind_of_relationship

    @property
    def numeric_reference_spei(self):
        """Gets the numeric_reference_spei of this Account.  # noqa: E501

        Es la referencia numérica a utilizar cuando se realice una transferencia y no se especifique una referencia.  # noqa: E501

        :return: The numeric_reference_spei of this Account.  # noqa: E501
        :rtype: str
        """
        return self._numeric_reference_spei

    @numeric_reference_spei.setter
    def numeric_reference_spei(self, numeric_reference_spei):
        """Sets the numeric_reference_spei of this Account.

        Es la referencia numérica a utilizar cuando se realice una transferencia y no se especifique una referencia.  # noqa: E501

        :param numeric_reference_spei: The numeric_reference_spei of this Account.  # noqa: E501
        :type: str
        """

        self._numeric_reference_spei = numeric_reference_spei

    @property
    def payment_concept_spei(self):
        """Gets the payment_concept_spei of this Account.  # noqa: E501

        Es el concepto de pago a utilizar cuando se realice una transferencia y no se especifique un concepto  # noqa: E501

        :return: The payment_concept_spei of this Account.  # noqa: E501
        :rtype: str
        """
        return self._payment_concept_spei

    @payment_concept_spei.setter
    def payment_concept_spei(self, payment_concept_spei):
        """Sets the payment_concept_spei of this Account.

        Es el concepto de pago a utilizar cuando se realice una transferencia y no se especifique un concepto  # noqa: E501

        :param payment_concept_spei: The payment_concept_spei of this Account.  # noqa: E501
        :type: str
        """

        self._payment_concept_spei = payment_concept_spei

    @property
    def person(self):
        """Gets the person of this Account.  # noqa: E501


        :return: The person of this Account.  # noqa: E501
        :rtype: Person
        """
        return self._person

    @person.setter
    def person(self, person):
        """Sets the person of this Account.


        :param person: The person of this Account.  # noqa: E501
        :type: Person
        """

        self._person = person

    @property
    def relationship(self):
        """Gets the relationship of this Account.  # noqa: E501

        Es la relación con el propietario de la cuenta, para registrar este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br/> <br/> <b>Nota:</b> Si en la respuesta de Monex, sta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :return: The relationship of this Account.  # noqa: E501
        :rtype: str
        """
        return self._relationship

    @relationship.setter
    def relationship(self, relationship):
        """Sets the relationship of this Account.

        Es la relación con el propietario de la cuenta, para registrar este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br/> <br/> <b>Nota:</b> Si en la respuesta de Monex, sta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :param relationship: The relationship of this Account.  # noqa: E501
        :type: str
        """
        if relationship is None:
            raise ValueError("Invalid value for `relationship`, must not be `None`")  # noqa: E501

        self._relationship = relationship

    @property
    def rfc(self):
        """Gets the rfc of this Account.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) de la persona o institución propietaria dela cuenta. <br/> <br/><b>Nota:</b> Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :return: The rfc of this Account.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this Account.

        Es el Registro Federal de Contribuyentes (RFC) de la persona o institución propietaria dela cuenta. <br/> <br/><b>Nota:</b> Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :param rfc: The rfc of this Account.  # noqa: E501
        :type: str
        """
        if rfc is None:
            raise ValueError("Invalid value for `rfc`, must not be `None`")  # noqa: E501

        self._rfc = rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Account, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AmountRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_limit': 'float',
        'cancel_return_url': 'str',
        'currency_code': 'str',
        'previous_amount_limit': 'float',
        'return_url': 'str'
    }

    attribute_map = {
        'amount_limit': 'amount_limit',
        'cancel_return_url': 'cancel_return_url',
        'currency_code': 'currency_code',
        'previous_amount_limit': 'previous_amount_limit',
        'return_url': 'return_url'
    }

    def __init__(self, amount_limit=None, cancel_return_url=None, currency_code=None, previous_amount_limit=None, return_url=None):  # noqa: E501
        """AmountRequest - a model defined in Swagger"""  # noqa: E501
        self._amount_limit = None
        self._cancel_return_url = None
        self._currency_code = None
        self._previous_amount_limit = None
        self._return_url = None
        self.discriminator = None
        self.amount_limit = amount_limit
        self.cancel_return_url = cancel_return_url
        self.currency_code = currency_code
        self.previous_amount_limit = previous_amount_limit
        self.return_url = return_url

    @property
    def amount_limit(self):
        """Gets the amount_limit of this AmountRequest.  # noqa: E501

        Es el nuevo monto límite que reemplazará al actual, un monto de 0.0 implica que no hay límite.  # noqa: E501

        :return: The amount_limit of this AmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._amount_limit

    @amount_limit.setter
    def amount_limit(self, amount_limit):
        """Sets the amount_limit of this AmountRequest.

        Es el nuevo monto límite que reemplazará al actual, un monto de 0.0 implica que no hay límite.  # noqa: E501

        :param amount_limit: The amount_limit of this AmountRequest.  # noqa: E501
        :type: float
        """
        if amount_limit is None:
            raise ValueError("Invalid value for `amount_limit`, must not be `None`")  # noqa: E501

        self._amount_limit = amount_limit

    @property
    def cancel_return_url(self):
        """Gets the cancel_return_url of this AmountRequest.  # noqa: E501

        Es la dirección URL a la que se redirigirá en caso de que el cliente cancele el registro. Se valida hasta 512 caracteres.  # noqa: E501

        :return: The cancel_return_url of this AmountRequest.  # noqa: E501
        :rtype: str
        """
        return self._cancel_return_url

    @cancel_return_url.setter
    def cancel_return_url(self, cancel_return_url):
        """Sets the cancel_return_url of this AmountRequest.

        Es la dirección URL a la que se redirigirá en caso de que el cliente cancele el registro. Se valida hasta 512 caracteres.  # noqa: E501

        :param cancel_return_url: The cancel_return_url of this AmountRequest.  # noqa: E501
        :type: str
        """
        if cancel_return_url is None:
            raise ValueError("Invalid value for `cancel_return_url`, must not be `None`")  # noqa: E501

        self._cancel_return_url = cancel_return_url

    @property
    def currency_code(self):
        """Gets the currency_code of this AmountRequest.  # noqa: E501

        Es el código de divisa de la cuenta. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :return: The currency_code of this AmountRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this AmountRequest.

        Es el código de divisa de la cuenta. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :param currency_code: The currency_code of this AmountRequest.  # noqa: E501
        :type: str
        """
        if currency_code is None:
            raise ValueError("Invalid value for `currency_code`, must not be `None`")  # noqa: E501

        self._currency_code = currency_code

    @property
    def previous_amount_limit(self):
        """Gets the previous_amount_limit of this AmountRequest.  # noqa: E501

        Es el monto límite registrado actualmente, un monto de 0.0 implica que no hay límite.  # noqa: E501

        :return: The previous_amount_limit of this AmountRequest.  # noqa: E501
        :rtype: float
        """
        return self._previous_amount_limit

    @previous_amount_limit.setter
    def previous_amount_limit(self, previous_amount_limit):
        """Sets the previous_amount_limit of this AmountRequest.

        Es el monto límite registrado actualmente, un monto de 0.0 implica que no hay límite.  # noqa: E501

        :param previous_amount_limit: The previous_amount_limit of this AmountRequest.  # noqa: E501
        :type: float
        """
        if previous_amount_limit is None:
            raise ValueError("Invalid value for `previous_amount_limit`, must not be `None`")  # noqa: E501

        self._previous_amount_limit = previous_amount_limit

    @property
    def return_url(self):
        """Gets the return_url of this AmountRequest.  # noqa: E501

        Es la dirección URL a la que se redirigirá en caso de éxito. Se valida hasta 512 caracteres.  # noqa: E501

        :return: The return_url of this AmountRequest.  # noqa: E501
        :rtype: str
        """
        return self._return_url

    @return_url.setter
    def return_url(self, return_url):
        """Sets the return_url of this AmountRequest.

        Es la dirección URL a la que se redirigirá en caso de éxito. Se valida hasta 512 caracteres.  # noqa: E501

        :param return_url: The return_url of this AmountRequest.  # noqa: E501
        :type: str
        """
        if return_url is None:
            raise ValueError("Invalid value for `return_url`, must not be `None`")  # noqa: E501

        self._return_url = return_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AmountRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AmountRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TransactionOutgoing(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'beneficiary_account': 'str',
        'beneficiary_bank_key': 'str',
        'concept': 'str',
        'currency_code': 'str',
        'email': 'list[str]',
        'order_id': 'str',
        'reference': 'int'
    }

    attribute_map = {
        'amount': 'amount',
        'beneficiary_account': 'beneficiary_account',
        'beneficiary_bank_key': 'beneficiary_bank_key',
        'concept': 'concept',
        'currency_code': 'currency_code',
        'email': 'email',
        'order_id': 'order_id',
        'reference': 'reference'
    }

    def __init__(self, amount=None, beneficiary_account=None, beneficiary_bank_key=None, concept=None, currency_code=None, email=None, order_id=None, reference=None):  # noqa: E501
        """TransactionOutgoing - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._beneficiary_account = None
        self._beneficiary_bank_key = None
        self._concept = None
        self._currency_code = None
        self._email = None
        self._order_id = None
        self._reference = None
        self.discriminator = None
        self.amount = amount
        self.beneficiary_account = beneficiary_account
        if beneficiary_bank_key is not None:
            self.beneficiary_bank_key = beneficiary_bank_key
        self.concept = concept
        self.currency_code = currency_code
        if email is not None:
            self.email = email
        self.order_id = order_id
        self.reference = reference

    @property
    def amount(self):
        """Gets the amount of this TransactionOutgoing.  # noqa: E501

        Monto de la transferencia  # noqa: E501

        :return: The amount of this TransactionOutgoing.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this TransactionOutgoing.

        Monto de la transferencia  # noqa: E501

        :param amount: The amount of this TransactionOutgoing.  # noqa: E501
        :type: float
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this TransactionOutgoing.  # noqa: E501

        Cuenta del beneficiario, podría ser un número celular, TDD o Cuenta CLABE interbancaria   # noqa: E501

        :return: The beneficiary_account of this TransactionOutgoing.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this TransactionOutgoing.

        Cuenta del beneficiario, podría ser un número celular, TDD o Cuenta CLABE interbancaria   # noqa: E501

        :param beneficiary_account: The beneficiary_account of this TransactionOutgoing.  # noqa: E501
        :type: str
        """
        if beneficiary_account is None:
            raise ValueError("Invalid value for `beneficiary_account`, must not be `None`")  # noqa: E501

        self._beneficiary_account = beneficiary_account

    @property
    def beneficiary_bank_key(self):
        """Gets the beneficiary_bank_key of this TransactionOutgoing.  # noqa: E501

        La clave del banco beneficiario, proprocionada por BANXICO, este campo solo es obligatario cuando la cuenta beneficiaria es un número celular (*).  # noqa: E501

        :return: The beneficiary_bank_key of this TransactionOutgoing.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_bank_key

    @beneficiary_bank_key.setter
    def beneficiary_bank_key(self, beneficiary_bank_key):
        """Sets the beneficiary_bank_key of this TransactionOutgoing.

        La clave del banco beneficiario, proprocionada por BANXICO, este campo solo es obligatario cuando la cuenta beneficiaria es un número celular (*).  # noqa: E501

        :param beneficiary_bank_key: The beneficiary_bank_key of this TransactionOutgoing.  # noqa: E501
        :type: str
        """

        self._beneficiary_bank_key = beneficiary_bank_key

    @property
    def concept(self):
        """Gets the concept of this TransactionOutgoing.  # noqa: E501

        Concepto de la transferencia  # noqa: E501

        :return: The concept of this TransactionOutgoing.  # noqa: E501
        :rtype: str
        """
        return self._concept

    @concept.setter
    def concept(self, concept):
        """Sets the concept of this TransactionOutgoing.

        Concepto de la transferencia  # noqa: E501

        :param concept: The concept of this TransactionOutgoing.  # noqa: E501
        :type: str
        """
        if concept is None:
            raise ValueError("Invalid value for `concept`, must not be `None`")  # noqa: E501

        self._concept = concept

    @property
    def currency_code(self):
        """Gets the currency_code of this TransactionOutgoing.  # noqa: E501

        Código de moneda en la que opera la cuenta  # noqa: E501

        :return: The currency_code of this TransactionOutgoing.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this TransactionOutgoing.

        Código de moneda en la que opera la cuenta  # noqa: E501

        :param currency_code: The currency_code of this TransactionOutgoing.  # noqa: E501
        :type: str
        """
        if currency_code is None:
            raise ValueError("Invalid value for `currency_code`, must not be `None`")  # noqa: E501

        self._currency_code = currency_code

    @property
    def email(self):
        """Gets the email of this TransactionOutgoing.  # noqa: E501

        Lista de email del beneficiario,es opcional  # noqa: E501

        :return: The email of this TransactionOutgoing.  # noqa: E501
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this TransactionOutgoing.

        Lista de email del beneficiario,es opcional  # noqa: E501

        :param email: The email of this TransactionOutgoing.  # noqa: E501
        :type: list[str]
        """

        self._email = email

    @property
    def order_id(self):
        """Gets the order_id of this TransactionOutgoing.  # noqa: E501

        Referencia de la transferencia asignada por el cliente  # noqa: E501

        :return: The order_id of this TransactionOutgoing.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this TransactionOutgoing.

        Referencia de la transferencia asignada por el cliente  # noqa: E501

        :param order_id: The order_id of this TransactionOutgoing.  # noqa: E501
        :type: str
        """
        if order_id is None:
            raise ValueError("Invalid value for `order_id`, must not be `None`")  # noqa: E501

        self._order_id = order_id

    @property
    def reference(self):
        """Gets the reference of this TransactionOutgoing.  # noqa: E501

        Referencia numérica de la transferencia  # noqa: E501

        :return: The reference of this TransactionOutgoing.  # noqa: E501
        :rtype: int
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this TransactionOutgoing.

        Referencia numérica de la transferencia  # noqa: E501

        :param reference: The reference of this TransactionOutgoing.  # noqa: E501
        :type: int
        """
        if reference is None:
            raise ValueError("Invalid value for `reference`, must not be `None`")  # noqa: E501

        self._reference = reference

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TransactionOutgoing, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionOutgoing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MessageInstitution(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company_name': 'str',
        'key': 'str',
        'name': 'str',
        'rfc': 'str'
    }

    attribute_map = {
        'company_name': 'company_name',
        'key': 'key',
        'name': 'name',
        'rfc': 'rfc'
    }

    def __init__(self, company_name=None, key=None, name=None, rfc=None):  # noqa: E501
        """MessageInstitution - a model defined in Swagger"""  # noqa: E501
        self._company_name = None
        self._key = None
        self._name = None
        self._rfc = None
        self.discriminator = None
        if company_name is not None:
            self.company_name = company_name
        if key is not None:
            self.key = key
        if name is not None:
            self.name = name
        if rfc is not None:
            self.rfc = rfc

    @property
    def company_name(self):
        """Gets the company_name of this MessageInstitution.  # noqa: E501

        Es el nombre de la institución bancaria registrada ante el Servicio de Administración Tributaria (SAT).  # noqa: E501

        :return: The company_name of this MessageInstitution.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this MessageInstitution.

        Es el nombre de la institución bancaria registrada ante el Servicio de Administración Tributaria (SAT).  # noqa: E501

        :param company_name: The company_name of this MessageInstitution.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def key(self):
        """Gets the key of this MessageInstitution.  # noqa: E501

        Es la clave de la institución bancaria.  # noqa: E501

        :return: The key of this MessageInstitution.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this MessageInstitution.

        Es la clave de la institución bancaria.  # noqa: E501

        :param key: The key of this MessageInstitution.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def name(self):
        """Gets the name of this MessageInstitution.  # noqa: E501

        Es el nombre de la institución bancaria.  # noqa: E501

        :return: The name of this MessageInstitution.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MessageInstitution.

        Es el nombre de la institución bancaria.  # noqa: E501

        :param name: The name of this MessageInstitution.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def rfc(self):
        """Gets the rfc of this MessageInstitution.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) de la institución.  # noqa: E501

        :return: The rfc of this MessageInstitution.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this MessageInstitution.

        Es el Registro Federal de Contribuyentes (RFC) de la institución.  # noqa: E501

        :param rfc: The rfc of this MessageInstitution.  # noqa: E501
        :type: str
        """

        self._rfc = rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageInstitution, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageInstitution):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de API. La API de Wire4 está organizada en torno a REST  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wire4_client.api_client import ApiClient


class SuscripcionesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def change_subscription_status_using_put(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Cambia el estatus de la suscripción  # noqa: E501

        Se cambia el estado o estatus de la suscripción a los posibles valores que son: ACTIVE o INACTIVE  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_subscription_status_using_put(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SubscriptionChangeStatusRequest body: request (required)
        :param str authorization: Header para token (required)
        :param str subscription: subscription (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_subscription_status_using_put_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.change_subscription_status_using_put_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
            return data

    def change_subscription_status_using_put_with_http_info(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Cambia el estatus de la suscripción  # noqa: E501

        Se cambia el estado o estatus de la suscripción a los posibles valores que son: ACTIVE o INACTIVE  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_subscription_status_using_put_with_http_info(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SubscriptionChangeStatusRequest body: request (required)
        :param str authorization: Header para token (required)
        :param str subscription: subscription (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_subscription_status_using_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `change_subscription_status_using_put`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `change_subscription_status_using_put`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `change_subscription_status_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/status', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_subscription_use_using_patch(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Cambia el uso de la suscripción  # noqa: E501

        Se asigna o cambia el uso y el estatus que se le dará a la subscripción para los servicios SPEI y SPID en el manejo de Cobros y Pagos El status puede tener los posibles valores: ACTIVE o INACTIVE. El uso puede tener los posibles valores: WITHDRAWAL_DEPOSIT o WITHDRAWAL o DEPOSIT  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_subscription_use_using_patch(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ServiceBanking body: request (required)
        :param str authorization: Header para token (required)
        :param str subscription: subscription (required)
        :return: ServiceBanking
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_subscription_use_using_patch_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.change_subscription_use_using_patch_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
            return data

    def change_subscription_use_using_patch_with_http_info(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Cambia el uso de la suscripción  # noqa: E501

        Se asigna o cambia el uso y el estatus que se le dará a la subscripción para los servicios SPEI y SPID en el manejo de Cobros y Pagos El status puede tener los posibles valores: ACTIVE o INACTIVE. El uso puede tener los posibles valores: WITHDRAWAL_DEPOSIT o WITHDRAWAL o DEPOSIT  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_subscription_use_using_patch_with_http_info(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ServiceBanking body: request (required)
        :param str authorization: Header para token (required)
        :param str subscription: subscription (required)
        :return: ServiceBanking
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_subscription_use_using_patch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `change_subscription_use_using_patch`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `change_subscription_use_using_patch`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `change_subscription_use_using_patch`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServiceBanking',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pre_enrollment_monex_user_using_post(self, body, authorization, **kwargs):  # noqa: E501
        """Pre-registro de una suscripción  # noqa: E501

        Pre-registra una suscripción para operar un contrato a través de un aplicación socio de la plataforma. Se retorna una dirección URL hacia el centro de autorización donde el cliente  Monex debe autorizar el acceso a los datos de su cuenta a el socio.<br/><br/>Una vez que el cuentahabiente autorice el acceso, se envía una notificación (webhook configurado) con el evento 'ENROLLMENT.CREATED', el cuál contiene los datos de acceso a esta API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pre_enrollment_monex_user_using_post(body, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PreEnrollmentData body: Información para la pre-suscripción (required)
        :param str authorization: Header para token (required)
        :return: PreEnrollmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.pre_enrollment_monex_user_using_post_with_http_info(body, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.pre_enrollment_monex_user_using_post_with_http_info(body, authorization, **kwargs)  # noqa: E501
            return data

    def pre_enrollment_monex_user_using_post_with_http_info(self, body, authorization, **kwargs):  # noqa: E501
        """Pre-registro de una suscripción  # noqa: E501

        Pre-registra una suscripción para operar un contrato a través de un aplicación socio de la plataforma. Se retorna una dirección URL hacia el centro de autorización donde el cliente  Monex debe autorizar el acceso a los datos de su cuenta a el socio.<br/><br/>Una vez que el cuentahabiente autorice el acceso, se envía una notificación (webhook configurado) con el evento 'ENROLLMENT.CREATED', el cuál contiene los datos de acceso a esta API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pre_enrollment_monex_user_using_post_with_http_info(body, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PreEnrollmentData body: Información para la pre-suscripción (required)
        :param str authorization: Header para token (required)
        :return: PreEnrollmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pre_enrollment_monex_user_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `pre_enrollment_monex_user_using_post`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `pre_enrollment_monex_user_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/pre-subscription', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PreEnrollmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_enrollment_user_using_delete(self, authorization, subscription, **kwargs):  # noqa: E501
        """Elimina suscripción por su identificador.  # noqa: E501

        Elimina una suscripción mediante su identificador. Una vez eliminada dicha suscripción, ya no se podrán realizar operaciones en el API utilizando sus credenciales  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_enrollment_user_using_delete(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: El identificador de la suscripción a ésta API (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_enrollment_user_using_delete_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_enrollment_user_using_delete_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
            return data

    def remove_enrollment_user_using_delete_with_http_info(self, authorization, subscription, **kwargs):  # noqa: E501
        """Elimina suscripción por su identificador.  # noqa: E501

        Elimina una suscripción mediante su identificador. Una vez eliminada dicha suscripción, ya no se podrán realizar operaciones en el API utilizando sus credenciales  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_enrollment_user_using_delete_with_http_info(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: El identificador de la suscripción a ésta API (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_enrollment_user_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `remove_enrollment_user_using_delete`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `remove_enrollment_user_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_subscription_pending_status_using_delete(self, authorization, subscription, **kwargs):  # noqa: E501
        """Elimina pre-registro de suscripción  # noqa: E501

        Se elimina el pre-registro de suscripción. Sólo se elimina en caso de que el cliente Monex no haya concedido su autorización de acceso (token), es decir que la suscripcion esté pendiente.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_subscription_pending_status_using_delete(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_subscription_pending_status_using_delete_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_subscription_pending_status_using_delete_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
            return data

    def remove_subscription_pending_status_using_delete_with_http_info(self, authorization, subscription, **kwargs):  # noqa: E501
        """Elimina pre-registro de suscripción  # noqa: E501

        Se elimina el pre-registro de suscripción. Sólo se elimina en caso de que el cliente Monex no haya concedido su autorización de acceso (token), es decir que la suscripcion esté pendiente.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_subscription_pending_status_using_delete_with_http_info(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_subscription_pending_status_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `remove_subscription_pending_status_using_delete`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `remove_subscription_pending_status_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/pre-subscription/{subscription}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
